@@ -48,6 +48,8 @@ struct _HTMLClueFlow {
 	HTMLListType item_type;
 	gint         item_number;
 	HTMLColor   *item_color;
+
+	HTMLDirection dir;
 };
 
 struct _HTMLClueFlowClass {
@@ -120,6 +122,7 @@ void               html_clueflow_spell_check                  (HTMLClueFlow
 							       HTMLEngine         *e,
 							       HTMLInterval       *i);
 gboolean           html_clueflow_is_empty                     (HTMLClueFlow       *flow);
+gboolean           html_clueflow_contains_table               (HTMLClueFlow       *flow);
 gint               html_clueflow_get_line_offset              (HTMLClueFlow       *flow,
 							       HTMLPainter        *painter,
 							       HTMLObject         *child);
